@@ -9,7 +9,7 @@ package Vote::Count;
 use namespace::autoclean;
 use Moose;
 
-# use Data::Printer;
+# use Data::Dumper;
 use Time::Piece;
 use Path::Tiny;
 use Vote::Count::Matrix;
@@ -17,14 +17,14 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='1.00';
+our $VERSION='1.03';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 1.00
+=head1 VERSION 1.03
 
 =cut
 
@@ -63,6 +63,13 @@ has TieBreakMethod => (
   required => 0,
 );
 
+# This is only used for the precedence tiebreaker!
+has PrecedenceFile => (
+  is       => 'rw',
+  isa      => 'Str',
+  required => 0,
+);
+
 has 'PairMatrix' => (
   is      => 'ro',
   isa     => 'Object',
@@ -103,12 +110,13 @@ sub BUILD {
 }
 
 # load the roles providing the underlying ops.
-with 'Vote::Count::Approval',
+with 
+  'Vote::Count::Approval',
   'Vote::Count::Borda',
   'Vote::Count::Floor',
   'Vote::Count::IRV',
   'Vote::Count::Log',
-  'Vote::Count::Range',
+  'Vote::Count::Score',
   'Vote::Count::TieBreaker',
   'Vote::Count::TopCount',
   ;
@@ -117,6 +125,25 @@ sub VotesCast ( $self ) {
   return $self->BallotSet()->{'votescast'};
 }
 
+sub VotesActive ( $self ) {
+  unless ( $self->BallotSet()->{'options'}{'rcv'} ) {
+    die "VotesActive Method only supports rcv"
+  }
+  my $set         = $self->BallotSet();
+  my $active      = $self->Active();
+  my $activeCount = 0;
+LOOPVOTESACTIVE:
+    for my $B ( values $set->{ballots}->%* ) {
+        for my $V ( $B->{'votes'}->@* ) {
+            if ( defined $active->{$V} ) {
+                $activeCount += $B->{'count'};
+                next LOOPVOTESACTIVE;
+            }
+        }
+    }
+  return $activeCount;
+}
+
 sub BallotSetType ( $self ) {
   if ( $self->BallotSet()->{'options'}{'rcv'} ) {
     return 'rcv';
@@ -139,15 +166,10 @@ __PACKAGE__->meta->make_immutable;
 =head1 Vote::Count
 
 
-=head2 A Toolkit for determining the outcome of Ranked Choice and other Alternative Balloting Strategies.
+=head2 A Toolkit for determining the outcome of Preferential Ballots.
 
 Provides a Toolkit for implementing multiple voting systems, allowing a wide range of method options. This library allows the creation of election resolution methods matching a set of Election Rules that are written in an organization's governing rules, and not requiring the bylaws to specify the rules of the software that will be used for the election, especially important given that many of the other libraries available do not provide a bylaws compatible explanation of their process.
 
-This is also extremely useful to researchers who may want to study multiple methods and variations of methods.
-
-
-=head1 Synopsis
-
   use 5.022; # Minimum Perl, or any later Perl.
   use feature qw /postderef signatures/;
 
@@ -175,6 +197,7 @@ This is also extremely useful to researchers who may want to study multiple meth
   my $Winner = $CondorcetElection->RunCondorcetDropping( $SmithSet )->{'winner'};
 
   # Create an object for IRV, use the same Floor as Condorcet
+
   my $IRVElection = Vote::Count->new(
     'BallotSet' => $ballotset,
     'Active' => $ChoicesAfterFloor );
@@ -194,15 +217,10 @@ This is also extremely useful to researchers who may want to study multiple meth
   # Now print the logs and winning information.
   say $CondorcetElection->logv();
   say $IRVElection->logv();
-  say 'B<>B<>B<>B<>**';
+  say '*'x60;
   say "Plurality Winner: $PluralityWinner->{'winner'}";
   say "IRV Winner: $IRVResult->{'winner'}";
-  say "Winner: $Winner";
-
-
-=head1 Preview Release
-
-This distribution is almost ready for production, but there may be changes made without notice up to stable release. Before putting it into production you should develop a suite of tests against test data. This will warn you of future changes that will break your code, so you can either update or freeze to an earlier version on BackPAN.
+  say "Condorcet Winner: $Winner";
 
 
 =head1 Overview
@@ -210,11 +228,11 @@ This distribution is almost ready for production, but there may be changes made
 
 =head2 Brief Review of Voting Methods
 
-Several alternatives have been proposed to the simple vote for a single choice method that has been used in most elections for a single member. In addition a number of different methods have been used for multiple members. For alternative single member voting, the three common alternatives are I<Approval> (voters indicate all choices that they approve of), I<Ranked Choice> (Voters rank the choices), and I<Score> also known as I<Range> (A Ranked Choice Ballot where the number of rankings is limited but voters may rank more than 1 choice at each rank).
+Several alternatives have been proposed to the simple vote for a single choice method that has been used in most elections for a single member. In addition a number of different methods have been used for multiple members. For alternative single member voting, the three common alternatives are I<Approval> (voters indicate all choices that they approve of), I<Ranked Choice> (Voters rank the choices), and I<Score> also known as I<Range> (voters give choices a score according to a scale).
 
 I<Vote for One> ballots may be resolved by one of two methods: I<Majority> and I<Plurality>. Majority vote requires a majority of votes to win (but frequently produces no winner), and Plurality which selects the choice with the most votes.
 
-Numerous methods have been proposed and tried for I<Ranked Choice Ballots>. To compare these methods a number of criteria have been developed. While Mathematicians often treat these criteria as absolutes, from a policy perspective it may be more valuable to see them as a spectrum where a method may be considered to satisfy or fail with varying degrees of severity. From a policy perspective it is appropriate to group several of the criteria into a single group: Consistency. Finally typically Mathematicians do not directly consider Complexity, but from a policy perspective this is just as important as any of the other criteria, and is definitely a scale not an absolute.
+Numerous methods have been proposed and tried for I<Ranked Choice Ballots>. To compare these methods a number of criteria have been developed. While Mathematicians often treat these criteria as absolutes, from a policy perspective it may be more valuable to see them as a spectrum where a method may be considered to satisfy or fail with varying degrees of severity. From a policy perspective it is appropriate to group most of the criteria into a single group: Consistency. Finally Mathematicians, typically, do not directly consider Complexity, but from a policy perspective this is just as important as any of the other criteria, and is definitely a scale not an absolute.
 
 
 =head3 The Criteria for Resolving Ranked Choice (including Score) Ballots
@@ -231,7 +249,7 @@ I<Condorcet Loser> states that a method should not choose a winner that would be
 
 I<Condorcet Winner> states a choice which defeats all others in direct matchups should be the Winner.
 
-I<Smith Criteria> if there is a set of choices which defeats all others in direct matchups the winner should be one of those choices.
+I<Smith Criteria> the winner should belong to the smallest set of choices which defeats all choices outside of that set.
 
 
 =head4 Consistency Criteria
@@ -242,7 +260,7 @@ To illustrate inconsistency: suppose every morning we vote on a flavor of Ice Cr
 
 Cloning occurs when similar choices are available, such as Vanilla and Vanilla Bean. If one of the clones would win without the presence of the other, the presence of both should not cause a non-clone to win.
 
-The cases described above: Monotonocity, Independence of Irrelevant Alternatives and Clone Independence are normally discussed as seperate criteria rather than components of one. Additional sub-criteria that haven't been mentioned include: Reversal Symmetry, Participation Consistency, and Later No Help (which could also be considered a sub-criteria of Later Harm).
+The cases described above: Monotonocity, Independence of Irrelevant Alternatives and Clone Independence are normally discussed as separate criteria rather than components of one. Additional sub-criteria that haven't been mentioned include: Reversal Symmetry, Participation Consistency, and Later No Help (which could also be considered a sub-criteria of Later Harm).
 
 There is a specific Criteria that is sometimes called Consistency, in this discussion consistency is discussed in the broad context. No method passes every possible consistency criteria, from a policy perspective a method is consistent if it has no major consistency failures.
 
@@ -259,7 +277,7 @@ I<Majority> meets all of the above criteria, however, unless votes are restricte
 
 =head4 Incentive for Strategic Voting
 
-Voting systems have weaknesses which can incentivize voter to vote in an insincere manner. Later Harm Violation is a strong driver for tactical voting. Inconsistency may create circumstances by which a block of voters by voting in certain ways can boost or harm a choice, this vulnerability type is often referred to as an attack, because successful exploitation violates the expectation that all voters have an equal impact on the outcome.
+Voting systems have weaknesses which can incentivize voters to vote in an insincere manner. Later Harm Violation is a strong driver for tactical voting. Inconsistency may create circumstances by which a block of voters by voting in certain ways can boost or harm a choice, this vulnerability type is often referred to as an attack.
 
 
 =head3 Arrow's Theorem
@@ -270,7 +288,7 @@ Arrows Theorem states that it is impossible to have a system that can resolve Ra
 =head3 Popular Ranked Choice Resolution Systems
 
 
-=head4 Instant Runoff Voting (IRV also known as Alternative Vote)
+=head4 Instant Runoff Voting (IRV is also known as Hare System, Alternative Vote)
 
 Seeks a Majority Winner. If there is none the lowest choice is eliminated until there is a Majority Winner or all remaining choices have the same number of votes.
 
@@ -299,9 +317,13 @@ Fails many Consistency Criteria (The example given for Consistency can happen wi
 =back
 
 
-=head4 Borda Count
+=head4 Borda Count and Scoring
 
-Scores choices on a ballot based on their position. Borda supporters often disagree about the weighting rule to use in the scoring. Iterative Borda Methods (Baldwin, Nansen) eliminate the lowest choice(s) and recalculate the Borda score ignoring  eliminated choices (if your second choice is eliminated your third choice is promoted).
+When Range (Cardinal) Ballots are used, the scores assigned by the voters are tallied to score the choices.
+
+Since Scoring is native to Range Ballots, to use the approach to resolve Ranked Ballots requires a method of assigning scores.
+
+Borda Count Scores choices on a ballot based on their position. Borda supporters often disagree about the weighting rule to use in the scoring. Iterative Borda Methods (Baldwin, Nansen) eliminate the lowest choice(s) and recalculate the Borda score ignoring eliminated choices (if your second choice is eliminated your third choice is promoted).
 
 =over
 
@@ -322,12 +344,12 @@ Fails Condorcet Winner.
 
 =item *
 
-Inconsistant.
+Inconsistent.
 
 
 =item *
 
-The basic Borda Method is vulnerable to a Cloning Attack.
+The basic Borda Method is vulnerable to a Cloning Attack, but not Range Ballot Scoring and iterative Borda methods.
 
 
 =back
@@ -370,18 +392,20 @@ When a Condorcet Winner is present Consistency is very high. When there is no Co
 
 =head3 Range (Score) Voting Systems
 
-Most Methods for Ranked Choice Ballots can be used for Range Ballots. Score Voting proposals typically implement I<Borda Count>, with a fixed depth of choices. I<STAR>, creates a virtual runoff between the top two I<Borda Count> Choices.
+Most Methods for Ranked Choice Ballots can be used for Range Ballots.
 
-Advocates claim that this Ballot Style is a better expression of voter preference. Where it shows a clear advantage is in allowing Voters to directly mitigate Later Harm by ranking a strongly favored choice with the highest score and weaker choices with the lowest.
+Score Voting proposals typically implement I<Borda Count>, with a fixed depth of choices. I<STAR>, creates a virtual runoff between the top two I<Borda Count> Choices.
 
-The Range Ballot resolves the Borda weighting problem and allows the voter to manage the later harm effect, so it is clearly the better choice for Borda. Condorcet and IRV can resolve Range Ballots, but ignore the extra information and would prefer strict ordinality (not allowing equal ranking).
+Advocates claim that this Ballot Style is a better expression of voter preference. Where it shows a clear advantage is in allowing Voters to directly mitigate Later Harm by ranking a strongly favored choice with the highest score and weaker choices with the lowest. The downside to this strategy is that the voter is giving little help to later choices reaching the automatic runoff. Given a case with two roughly equal main factions, where one faction give strong support to all of its options, and the other faction's supporters give weak support to all later choices; the runoff will be between the two best choices of the first faction, even if the choices of the second faction all defeat any of the first's choices in pairwise comparison.
 
-Voters may find the Range Ballot to be more complex than the Ranked Choices Ballot.
+The Range Ballot resolves the Borda weighting problem and allows the voter to manage the later harm effect, so it is clearly a better choice than Borda. Condorcet and IRV can resolve Range Ballots, but ignore the extra information and would prefer strict ordinality (not allowing equal ranking).
+
+Voters may find the Range Ballot to be more complex than the Ranked Choice Ballot.
 
 
 =head1 Objective and Motivation
 
-I wanted to be able to evaluate alternative methods for resolving elections and couldn't find a flexible enough existing libary in any of the popular general purpose and web development languages: Perl, PHP, Python, Ruby, JavaScript, nor in the newer language Julia (created as an alternative to R and other math languages). More recently I was writing a bylaws proposal to use RCV and found that the existing libraries and services were not only constrained in what options they can provide, but also didn't always document them clearly, making it a challenge to have a method described in bylaws where it could be guaranteed hand and machine counts would agree.
+I wanted to be able to evaluate alternative methods for resolving elections and couldn't find a flexible enough existing library in any of the popular general purpose and web development languages: Perl, PHP, Python, Ruby, JavaScript, nor in the newer language Julia (created as an alternative to R and other math languages). More recently I was writing a bylaws proposal to use RCV and found that the existing libraries and services were not only constrained in what options they can provide, but also didn't always document them clearly, making it a challenge to have a method described in bylaws where it could be guaranteed hand and machine counts would agree.
 
 The objective is to have a library that can handle any of the myriad variants that one might consider either from a study perspective or what is called for by the elections rules of our entity.
 
@@ -436,7 +460,7 @@ When logging from your methods, use logt for events that produce a summary, use
 
 =head3 Active Sets
 
-Active sets are typically represented as a Hash Reference where the keys represent the active choices, the values are ignored. The VoteCount Object contains an Active Set which can be Accessed or set via the ->Active() method. The ->GetActive and ->SetActive methods are preferred because they break the reference link between the object's copy and the external copy of the Active set.
+Active sets are typically represented as a Hash Reference where the keys represent the active choices and the value is true. The VoteCount Object contains an Active Set which can be Accessed or set via the ->Active() method. The ->GetActive and ->SetActive methods are preferred because they break the reference link between the object's copy and the external copy of the Active set.
 
 Most Components will take an argument for $activeset or default to the current Active set of the Vote::Count object, which will default to the Choices defined in the BallotSet.
 
@@ -457,6 +481,24 @@ Active: Set or Get Active Set as HashRef
 
 
 
+=item *
+
+ResetActive: Sets the Active Set to the full choices list of the BallotSet.
+
+
+
+=item *
+
+SetActive: Sets the Active Set to provided HashRef. Using the Active method may preserve a reference between the Active Set and the HashRef, SetActive will not. The values to the hashref should evaluate as True.
+
+
+
+=item *
+
+SetActiveFromArrayRef: Same as SetActive except it takes an ArrayRef of the choices to be set as Active.
+
+
+
 =item *
 
 BallotSet: Get BallotSet
@@ -481,6 +523,12 @@ VotesCast: Returns the number of votes cast.
 
 
 
+=item *
+
+VotesActive: Returns the number of non-exhausted ballots based on the current Active Set.
+
+
+
 =back
 
 
@@ -535,6 +583,11 @@ L<Vote::Count::TopCount|https://metacpan.org/pod/Vote::Count::TopCount>
 L<Vote::Count::Redact|https://metacpan.org/pod/Vote::Count::Redact>
 
 
+=item *
+
+L<Vote::Count::Score|https://metacpan.org/pod/Vote::Count::Score>
+
+
 =item *
 
 L<Vote::Count::TieBreaker|https://metacpan.org/pod/Vote::Count::TieBreaker>
@@ -630,6 +683,11 @@ L<Catalog|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Catalog.pod>
 L<Hand Count|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Hand_Count.pod>
 
 
+=item *
+
+L<Multi Member|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/MultiMember.pod>
+
+
 =item *
 
 L<Vote::Count::Start|https://metacpan.org/pod/Vote::Count::Start>
@@ -663,7 +721,7 @@ STAR is handcountable but requires a Range Ballot. Range methods like STAR have
 
 I<Redacting Condorcet Methods> are the B<best> for a conventional Ranked Choice Ballot. If a Condorcet Winner does not create a Later Harm violation they will always be chosen. They can create a gauge of the later harm effect that then allows for the establishment of a Later Harm tolerance. The steps for I<Condorcet Vs IRV> are easy to understand but the number of steps qualifies it as somewhat complex. Other methods in the family (not yet implemented) will be more complex.
 
-B<STAR> and B<Redacting Condorcet> (Condorcet Vs IRV being the only one available here at the moment) are my preference. If you need to hand count, Benham is your Condorcet Method and IRV is your Later Harm Protected Method. Smith Set IRV is a simple Condorcet Method that is better on Later Harm than any other non-redacting Condorcer Method, it is a much better choice than Benham. If Later Harm compliance is required a Redacting Condorcet Method is your best choice, and IRV your choice if they're too complex.
+B<Redacting Condorcet> (Condorcet Vs IRV being the only one available here at the moment) is my preference. B<STAR> is my preferred Scoring method. If you need to hand count, Benham is your Condorcet Method and IRV is your Later Harm Protected Method. Smith Set IRV is a simple Condorcet Method that is better on Later Harm than any other non-redacting Condorcer Method, it is a much better choice than Benham. If Later Harm compliance is required a Redacting Condorcet Method is your best choice, and IRV your choice if they're too complex.
 
 
 =head2 Floor Rules and Tie Breakers
